/*
 * [AshWednesday.java]
 *
 * Summary: calculate when Ash Wednesday occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when Ash Wednesday occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class AshWednesday extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "Felix Gursky";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1583;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Ash Wednesday";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "46 days prior to Easter.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return new EasterSunday().when( year, false ) - 46;
        }// end when.
    }
