/*
 * [ParentsDay.java]
 *
 * Summary: calculate when Parents day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common11.BigDate;

/**
 * calculate when Parents day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class ParentsDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.parentsday.com/";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1994;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Parents' Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Fourth Sunday in July.\n"
               + "Promoted by Reverend Sun Myung Moon and the Washington Times\n"
               + "and proclaimed by president Clinton in 1994.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        if ( year < 1994 )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 4, BigDate.SUNDAY, year, BigDate.JUL );
        }// end when.
    }
