/*
 * [StAndrewsDay.java]
 *
 * Summary: calculate when St. Andrew's day occurs.
 *
 * Copyright: (c) 1999-2011 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.5+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;
// com.mindprod.holidays.StAndrewsDay

import com.mindprod.common11.BigDate;

/**
 * calculate when St. Andrew's day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class StAndrewsDay extends HolInfo
    {
    // -------------------------- PUBLIC INSTANCE  METHODS --------------------------

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.bbc.co.uk/religion/religions/christianity/saints/andrew.shtml";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 732;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "St. Andrews Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "November 30";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 11, 30 ),
                shift );
        }// end when.
    }
